@@ -17,6 +17,8 @@
 import copy
 import json
 import os
+import random
+import string
 import time
 
 from tempest import config
@@ -79,6 +81,7 @@ class SolumClient(rest_client.RestClient):
         self.created_assemblies = []
         self.created_plans = []
         self.created_apps = []
+        self.created_lps = []
 
     def request_without_auth(self, resource, method, headers={}, body=None):
         dscv = CONF.identity.disable_ssl_certificate_validation
@@ -124,6 +127,16 @@ class SolumClient(rest_client.RestClient):
             self.created_plans.append(uuid)
         return plan_resp
 
+    def create_lp(self, data=None):
+        sample_lp = dict()
+        s = string.lowercase
+        sample_lp["name"] = "lp" + ''.join(random.sample(s, 5))
+        lp_url = "https://github.com/murali44/Solum-lp-Go.git"
+        sample_lp["source_uri"] = lp_url
+        jsondata = json.dumps(sample_lp)
+        resp, body = self.post('v1/language_packs', jsondata)
+        return sample_lp["name"]
+
     def create_app(self, data=None):
         app_data = copy.deepcopy(data) or apputils.get_sample_data()
         json_data = json.dumps(app_data)
@@ -149,6 +162,17 @@ class SolumClient(rest_client.RestClient):
         [self.delete_plan(uuid) for uuid in list(self.created_plans)]
         self.created_plans = []
 
+    def delete_created_lps(self):
+        resp, body = self.get('v1/language_packs')
+        data = json.loads(body)
+        [self._delete_language_pack(pl['uuid']) for pl in data]
+
+    def _delete_language_pack(self, uuid):
+        resp, _ = self.delete('v1/language_packs/%s' % uuid)
+
+    def delete_language_pack(self, name):
+        resp, _ = self.delete('v1/language_packs/%s' % name)
+
     def delete_created_apps(self):
         self.delete_created_assemblies()
         [self.delete_app(id) for id in list(self.created_apps)]
@@ -158,7 +182,8 @@ class SolumClient(rest_client.RestClient):
         resp, body = self.delete(
             'v1/apps/%s' % id,
             headers={'content-type': 'application/json'})
-        self.created_apps.remove(id)
+        if id in self.created_apps:
+            self.created_apps.remove(id)
         return resp, body
 
     def delete_plan(self, uuid):
