@@ -16,6 +16,7 @@
 
 import ast
 import base64
+import json
 import os
 import random
 import shelve
@@ -97,6 +98,13 @@ def get_parameter_by_assem_id(ctxt, assembly_id):
     assem = get_assembly_by_id(ctxt, assembly_id)
     param_obj = solum.objects.registry.Parameter.get_by_plan_id(ctxt,
                                                                 assem.plan_id)
+
+    if not param_obj:
+        plan = solum.objects.registry.Plan.get_by_id(ctxt, assem.plan_id)
+        app = solum.objects.registry.App.get_by_id(ctxt, plan.uuid)
+        app = json.loads(app.raw_content)
+        param_obj = app['parameters']
+
     return param_obj
 
 
@@ -155,6 +163,23 @@ class Handler(object):
     def echo(self, ctxt, message):
         LOG.debug("%s" % message)
 
+    @exception.wrap_keystone_exception
+    def get_du_details(self, ctxt, du_id):
+        du_loc = None
+        du_name = None
+        du_image_backend = cfg.CONF.worker.image_storage
+
+        if du_image_backend.lower() == 'glance':
+            img = clients.OpenStackClients(ctxt).glance().images.get(du_id)
+            du_loc = img.id
+            du_name = img.name
+        elif du_image_backend.lower() == 'swift':
+            raise exception.NotImplemented()
+        else:
+            LOG.error("Invalid image storage option.")
+            raise exception.ResourceNotFound()
+        return du_loc, du_name
+
     @exception.wrap_keystone_exception
     def _get_environment(self, ctxt, source_uri, assembly_id=None,
                          test_cmd=None, run_cmd=None, lp_access=None):
@@ -298,8 +323,8 @@ class Handler(object):
 
         with open(user_param_file, 'w') as f:
             f.write("#!/bin/bash\n")
-            if param_obj.user_defined_params:
-                for k, v in param_obj.user_defined_params.items():
+            if param_obj.get('user_params'):
+                for k, v in param_obj['user_params'].items():
                     if k and k.startswith('_SYSTEM'):
                         # Variables for control purpose, e.g. _SYSTEM_USE_DRONE
                         param_env[k] = _sanitize_param(v)
@@ -307,8 +332,8 @@ class Handler(object):
                         f.write("export %s=%s\n" % (k, _sanitize_param(v)))
         with open(solum_param_file, 'w') as f:
             f.write("#!/bin/bash\n")
-            if param_obj.sys_defined_params:
-                for k, v in param_obj.sys_defined_params.items():
+            if param_obj.get('solum_params'):
+                for k, v in param_obj['solum_params'].items():
                     if k == 'REPO_DEPLOY_KEYS':
                         # Pass in deploy key as an environment variable
                         param_env[k] = self._get_private_key(v, source_uri)
@@ -320,7 +345,8 @@ class Handler(object):
 
     def launch_workflow(self, ctxt, build_id, git_info, ports, name,
                         base_image_id, source_format, image_format,
-                        assembly_id, workflow, test_cmd, run_cmd):
+                        assembly_id, workflow, test_cmd, run_cmd, du_id):
+
         if 'unittest' in workflow:
             if self._do_unittest(ctxt, build_id, git_info, name, base_image_id,
                                  source_format, image_format, assembly_id,
@@ -334,9 +360,19 @@ class Handler(object):
                 ctxt, build_id, git_info, name, base_image_id, source_format,
                 image_format, assembly_id, run_cmd)
 
-        if 'deploy' in workflow and du_image_loc and du_image_name:
-            self._do_deploy(ctxt, assembly_id, ports, du_image_loc,
-                            du_image_name)
+        if 'deploy' in workflow:
+            if du_id:
+                du_image_loc, du_image_name = self.get_du_details(ctxt, du_id)
+            if du_image_loc and du_image_name:
+                self._do_deploy(ctxt, assembly_id, ports, du_image_loc,
+                                du_image_name)
+            else:
+                LOG.warning("Deploy called without DU details. "
+                            "Cannot continue.")
+                return
+
+        if 'scale' in workflow:
+            self._do_scale(ctxt, assembly_id)
 
     def build(self, ctxt, build_id, git_info, name, base_image_id,
               source_format, image_format, assembly_id, run_cmd):
@@ -355,6 +391,9 @@ class Handler(object):
                                               image_name=du_image_name,
                                               ports=ports)
 
+    def _do_scale(self, ctxt, assembly_id):
+        deployer_api.API(context=ctxt).scale(assembly_id=assembly_id)
+
     def _do_build(self, ctxt, build_id, git_info, name, base_image_id,
                   source_format, image_format, assembly_id, run_cmd):
         update_assembly_status(ctxt, assembly_id, ASSEMBLY_STATES.BUILDING)
@@ -372,8 +411,8 @@ class Handler(object):
             if (not image or not image.project_id or not image.status or
                     not image.external_ref or not image.docker_image_name or
                     image.status.lower() != 'ready'):
-                LOG.warn("Error building due to language pack not ready."
-                         " assembly ID: %s" % assembly_id)
+                LOG.warning("Error building due to language pack not ready."
+                            " assembly ID: %s" % assembly_id)
                 job_update_notification(ctxt, build_id, IMAGE_STATES.ERROR,
                                         description='language pack not ready',
                                         assembly_id=assembly_id)
@@ -500,8 +539,8 @@ class Handler(object):
             if (not image or not image.project_id or not image.status or
                     not image.external_ref or not image.docker_image_name or
                     image.status.lower() != 'ready'):
-                LOG.warn("Error running unittest due to language pack"
-                         " not ready. assembly ID: %s" % assembly_id)
+                LOG.warning("Error running unittest due to language pack"
+                            " not ready. assembly ID: %s" % assembly_id)
                 update_assembly_status(ctxt, assembly_id,
                                        ASSEMBLY_STATES.ERROR)
                 return
